@@ -12,15 +12,15 @@ sub test_main : Tests {
     return unless $self->require_executable('node');
     return unless $self->require_executable('cssunminifier');
 
-    my $source = 'body {\nfont-family:helvetica;\nfont-size:15pt;\n}';
+    my $source = "body {\nfont-family:helvetica;\nfont-size:15pt;\n}";
     $self->tidyall(
         source      => $source,
-        expect_tidy => 'body {\n    font-family: helvetica;\n    font-size: 15pt;\n}\n'
+        expect_tidy => "body {\n    font-family: helvetica;\n    font-size: 15pt;\n}\n"
     );
     $self->tidyall(
         source      => $source,
         conf        => { argv => '-w=2' },
-        expect_tidy => 'body {\n  font-family: helvetica;\n  font-size: 15pt;\n}\n'
+        expect_tidy => "body {\n  font-family: helvetica;\n  font-size: 15pt;\n}\n"
     );
 }
 
